@@ -25,6 +25,10 @@
  * 
  */
 
+#include	<config.h>
+
+#ifndef	MINI_KON
+
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<unistd.h>
@@ -125,3 +129,5 @@ int	SocketSendData(u_char *buff, int size, int fd)
 	}
 	return(0);
 }
+
+#endif
