@@ -25,13 +25,13 @@
  * 
  */
 
+#include	<config.h>
+
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<string.h>
 #include	<unistd.h>
-#ifdef __FreeBSD__
 #include        <errno.h>
-#endif
 
 #include	<getcap.h>
 
@@ -53,6 +53,8 @@ static int	ConfigStartup(const char *string)
 	return SUCCESS;
 }
 
+#ifndef	MINI_KON
+
 static void	RunStartupCmd(void)
 {
 	char *p;
@@ -78,6 +80,8 @@ void	ChildInit(void)
 	DefineCap("StartUp", ConfigStartup, NULL);
 }
 
+#endif
+
 void	ChildCleanup(void)
 {
 	free(startupStr);
@@ -86,16 +90,21 @@ void	ChildCleanup(void)
 void	ChildStart(FILE *errfp)
 {
 	char	*shell, *tail, *tcap;
-	char	buff[80];
+	char	buff[256];
 
+#ifndef	MINI_KON
 	setgid(getgid());
 	setuid(getuid());
 
 	RunStartupCmd();
+#endif
 
 #if defined(linux)
-	sprintf(buff, "TERMCAP=:co#%d:li#%d:tc=console:",
-		dInfo.txmax + 1, dInfo.tymax + 1);
+#ifdef	MINI_KON
+	sprintf(buff, "TERM=linux");
+#else
+	sprintf(buff, "TERM=kon");
+#endif
 #elif defined(__FreeBSD__)
 	sprintf(buff,"TERM=vt100");
 #endif
@@ -103,6 +112,7 @@ void	ChildStart(FILE *errfp)
 	tcap = strdup(buff);
 	putenv(tcap);
 
+#ifndef	MINI_KON
 	if (startupMessage)
 	    printf("\rKON2 Kanji On Console " VERSION
 		   " using VT number %c\r\n"
@@ -117,12 +127,8 @@ void	ChildStart(FILE *errfp)
 	printf("\rKON for FreeBSD-2.x ver0.01 Takashi OGURA\r\n");
 #endif
 
-
-/*
-	printf("KON using VT number %c.\n\n",
-	       *(ttyname(fileno(errfp))+8));
-*/
 	fflush(stdout);
+#endif
 
 	if (execProg)
 	    execlp(execProg, execProg, 0);
