@@ -224,6 +224,9 @@ void VgaInit(void)
     /* save font data in plane 2 */
     PortOutw(0x0204, VGAGRP_ADDR);
     memcpy(fontBuff1, gramMem, FONT_SIZE);
+#ifdef	USE_ROMFONT
+    VgaLoadRomFont(fontBuff1);
+#endif
     if (savePlane3) {
 	/* save font data in plane 3 */
 	PortOutw(0x0304, VGAGRP_ADDR);
@@ -338,6 +341,8 @@ void VgaSput(u_char *code, u_char fc, u_char bc)
     VgaOutByte(0xFF);
 }
 
+#ifndef	MINI_KON
+
 void VgaWputFm(u_char *code, u_char fc, u_char bc)
 {
     volatile char	*gram, *vcls;
@@ -382,7 +387,7 @@ void VgaSputFm(u_char *code, u_char fc, u_char bc)
 /*    if (!code) return;*/
     VgaSetColor(fc);
     if (bc & 0x8) *(vcls - dInfo.glineByte) = 0;
-    for (x = 0;x < sbFReg->high;x ++, code ++, fm >>= 1) {
+    if (code) for (x = 0;x < sbFReg->high;x ++, code ++, fm >>= 1) {
 	if (*code) {
 	    VgaOutByte(*code);
 	    *gram = *gram;
@@ -392,6 +397,7 @@ void VgaSputFm(u_char *code, u_char fc, u_char bc)
     }
     VgaOutByte(0xFF);
 }
+#endif
 
 void VgaHardScrollUp(int line)
 {
@@ -439,6 +445,12 @@ void VgaHardScrollDown(int line)
 
 void VgaSetCursorAddress(struct cursorInfo *ci, u_int x, u_int y)
 {
+#if 0
+    if (x > dInfo.txmax) {
+	y ++;
+	x -= dInfo.txmax + 1;
+    }
+#endif
     ci->addr = (y * dInfo.tlineByte + cursorTop
 		* dInfo.glineByte + x + gramHead) % dInfo.gsize;
 }
@@ -469,7 +481,6 @@ void VgaCursor(struct cursorInfo *ci)
     } else
 	for (;x < bottom;x ++, gram += dInfo.glineByte)
 	    *gram = *gram;
-    
     PortOutw(0x0003, VGAGRP_ADDR);	/* unmodify mode */
 }
 
@@ -536,6 +547,7 @@ int VgaReadNewRegs(const char *str, union videoTimings *video)
     dInfo.glineByte = dInfo.gxdim >> 3;
     dInfo.gydim = dInfo.glineChar * (dInfo.tymax + 1);
     dInfo.gsize = dInfo.glineByte * dInfo.gydim;
+/*printf("%ld\r\n", dInfo.gsize);*/
     dInfo.tlineByte = dInfo.glineChar * dInfo.glineByte;
 
     if (video->m.vLine < 480) {
@@ -726,6 +738,8 @@ void VgaDefaultCaps()
     DefineCap("CursorBottom", ConfigCursorBottom, "15");
 }
 
+#ifndef	MINI_KON
+
 int VgaFmSetVideoType(struct videoInfo *info, const char *regs)
 {
     union videoTimings video;
@@ -739,5 +753,6 @@ int VgaFmSetVideoType(struct videoInfo *info, const char *regs)
     VgaDefaultCaps();
     return SUCCESS;
 }
+#endif
 
 #endif
