@@ -25,6 +25,8 @@
  * 
  */
 
+#include <config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -34,11 +36,16 @@
 #include <version.h>
 #include <term.h>
 
-void main(int argc, const char *argv[])
+void
+main(int argc, const char *argv[])
 {
-    char	*p;
+    extern void ChangeNewConsole();
 
+#ifdef	MINI_KON
+    fprintf(stderr, "Kanji ON Console MINI " VERSION "\n\n");
+#else
     fprintf(stderr, "Kanji ON Console " VERSION "\n\n");
+#endif
     if (geteuid() != 0) {
 	fprintf(stderr, "can not get I/O permissions.\n");
 	exit(EXIT_FAILURE);
