@@ -33,6 +33,8 @@
 
 #include	<config.h>
 
+#ifndef	MINI_KON
+
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<unistd.h>
@@ -93,11 +95,7 @@ int	SocketInit(char *tty)
 	PerrorExit(sinfo.sa_data);
     }
     sinfo.sa_family = AF_UNIX;
-#if defined(linux)
-    len = sizeof(sinfo.sa_family) + strlen(sinfo.sa_data);
-#elif defined(__FreeBSD__)
     len = sizeof(sinfo.sa_family) + strlen(sinfo.sa_data) + 1;
-#endif
     if (bind(sfd, &sinfo, len) < 0) {
 	message("can't bind socket");
 	PerrorExit(sinfo.sa_data);
@@ -147,3 +145,4 @@ void	SocketInterface(int sfd)
     }
     close(fd);
 }
+#endif
