@@ -29,12 +29,9 @@
 #include	<stdlib.h>
 #include	<unistd.h>
 #include	<string.h>
-#if defined(linux)
-#include	<termio.h>
-#elif defined(__FreeBSD__)
 #include	<termios.h>
+#if defined(__FreeBSD__)
 #include	<machine/console.h>
-#define termio termios
 #endif
 #include	<signal.h>
 #include	<errno.h>
@@ -52,14 +49,20 @@
 
 #include	<defs.h>
 #include	<errors.h>
+#ifndef	MINI_KON
 #include	<setutmp.h>
+#endif
 #include	<version.h>
 #include	<vc.h>
 #include	<vt.h>
 #include	<child.h>
 #include	<interface.h>
 #include	<sock.h>
+#ifdef	MINI_KON
+static int mouseFd=-1;
+#else
 #include	<mouse.h>
+#endif
 
 #ifdef __FreeBSD__
 #define TCSETA     TIOCSETA
@@ -73,7 +76,7 @@ int	masterPty;			 /* master pseudo-tty file descriptor */
 #define	MAX_TTYNAME	10
 
 static int	childPid, sockFd, slavePty;
-static struct termio	oldTio;
+static struct termios	oldTio;
 static char	ptyName[MAX_TTYNAME + 1];
 static int orgVtNum = -1;
 
@@ -81,7 +84,7 @@ struct initInfo {
     bool display;			 /* display initialized */
     bool utmp;			 /* utmp set */
     bool socket;			 /* socket opened */
-    bool termio;			 /* termio saved */
+    bool termios;			 /* termios saved */
 };
 
 static struct initInfo init;
@@ -91,19 +94,23 @@ static void	CleanUp(void)
     if (init.display && con.active) {
 	TextMode();
     }
+#ifndef	MINI_KON
     if (init.utmp)
 	ResetUtmp(ptyName);
     if (init.socket)
 	SocketKill(sockFd);
-    if (init.termio)
-	ioctl(0, TCSETA, &oldTio);
+#endif
+    if (init.termios)
+	tcsetattr(0, TCSAFLUSH, &oldTio);
     signal(SIGCHLD, SIG_DFL);
     signal(SIGHUP, SIG_DFL);
     signal(SIGTERM, SIG_DFL);
     signal(SIGSEGV, SIG_DFL);
     signal(SIGUSR1, SIG_DFL);
     signal(SIGUSR2, SIG_DFL);
+#ifndef	MINI_KON
     FontDetach(TRUE);
+#endif
 }
 
 static void	ExitTerm(int signum)
@@ -143,6 +150,7 @@ static void	ExitPty(int signum)
 static fd_set orgReadFds;
 static int numFds;
 
+#ifndef	MINI_KON
 void MouseSetRfd(int mfd)
 {
     if (mfd > 0) FD_SET(mfd, &orgReadFds);
@@ -155,6 +163,7 @@ void MouseResetRfd(int mfd)
     if (mfd > 0) FD_CLR(mfd, &orgReadFds);
     numFds = sockFd + 1;
 }
+#endif
 
 static void	ConsoleHandler(void)
 {
@@ -166,11 +175,15 @@ static void	ConsoleHandler(void)
     FD_ZERO(&orgReadFds);
     FD_SET(0, &orgReadFds);
     FD_SET(masterPty, &orgReadFds);
+#ifdef	MINI_KON
+    numFds = masterPty + 1;
+#else
     FD_SET(sockFd, &orgReadFds);
     if (mInfo.has_mouse && mouseFd > 0)
 	MouseSetRfd(mouseFd);
     else
 	MouseResetRfd(mouseFd);
+#endif
     /* Note: we use timeout on select call even if cursor blink is off
        because of screen saver and mouse cursor timeout. */
     while (1) {
@@ -204,6 +217,7 @@ static void	ConsoleHandler(void)
 	    if (i > 0) write(masterPty, buff, i);
 	    PollCursor(TRUE);
 	}
+#ifndef	MINI_KON
 	if (FD_ISSET(sockFd, &readFds)) SocketInterface(sockFd);
 	if (mInfo.has_mouse) {
 	    if (FD_ISSET(mouseFd, &readFds) && con.active) {
@@ -212,6 +226,7 @@ static void	ConsoleHandler(void)
 		PollCursor(TRUE);
 	    }
 	}
+#endif
     }
 }
 
@@ -219,6 +234,7 @@ static void	ProcessArgs(int argc, const char *argv[])
 {
     int	i = 0;
     const	char *video = "NORMAL";
+    extern int ConfigExecProg(const char *);
     
     if (argc > 0 && argv[0][0] != '-') {
 	video = argv[0];
@@ -254,12 +270,16 @@ void	TermInit(int argc, const char *argv[])
 {
     int	i;
     
-    init.display = init.utmp = init.socket = init.termio = FALSE;
+    init.display = init.utmp = init.socket = init.termios = FALSE;
     /* Initialize subsystems. */
     
     CapInit();
+
+#ifndef	MINI_KON
     ChildInit();
     MouseInit();
+#endif
+
     VtInit();
     ProcessArgs(argc, argv);
     savedArgc = argc;
@@ -280,13 +300,15 @@ static int	TryTermReset(int argc, const char *argv[])
     fprintf(stderr, " ]...\r\n");
     CapInit();
     ConsoleCleanup();
+#ifndef	MINI_KON
     if (mInfo.has_mouse)
 	MouseCleanup();
+    MouseInit();
+#endif
 #if 0
     VtCleanup();
 #endif
     init.display = FALSE;
-    MouseInit();
     VtInit();
     ProcessArgs(argc, argv);
     return ReadConfig(CONFIG_NAME);
@@ -314,8 +336,10 @@ void	TermRestart(int fd)
 	TryTermReset(savedArgc, savedArgv) < 0 &&
 	TryTermReset(0, (const char **)NULL) < 0)
 	fatal("giving up\r\n");
+#ifndef	MINI_KON
     if (mInfo.has_mouse)
 	mouseFd = MouseStart();
+#endif
     VtStart();
     ConsoleStart();
     init.display = TRUE;
@@ -325,8 +349,11 @@ void	TermRestart(int fd)
 /* Start processing */
 void	TermStart(void)
 {
-    struct termio	newTio;
+    struct termios	newTio;
     char	ls, ln;
+#ifdef	MINI_KON
+    extern void LoadMiniFont();
+#endif
     
     /* Open PTY(master) */
     for (ls = 'p'; ls <= 's'; ls ++) {
@@ -342,23 +369,29 @@ void	TermStart(void)
     }
     ptyName[5] = 't';
 
+#ifndef	MINI_KON
     if (mInfo.has_mouse) {
 	mouseFd = MouseStart();
     }
+#endif
 
+#ifndef	MINI_KON
     chown("/dev/tty0", getuid(), getgid());
 #if defined(linux)
     sockFd = SocketInit(ttyname(0) + 8);
 #elif defined(__FreeBSD__)
     sockFd = SocketInit(ttyname(0) + 9);
+#endif
 #endif
     init.socket = TRUE;
 
     /* Get old tio of 0 */
-    ioctl(0, TCGETA, &oldTio);
-    init.termio = TRUE;
+    tcgetattr(0, &oldTio);
+    init.termios = TRUE;
     
+#ifndef	MINI_KON
     SetUtmp(ptyName);
+#endif
     init.utmp = TRUE;
 
     /* fork handler */
@@ -370,6 +403,9 @@ void	TermStart(void)
 	atexit(CleanUp);
 	ChildCleanup();
 
+#ifdef	MINI_KON
+	LoadMiniFont();
+#endif
 	/* Signal Setting */
 	signal(SIGCHLD, ExitPty);
 	signal(SIGHUP, ExitTerm);
@@ -396,12 +432,14 @@ void	TermStart(void)
 #ifdef linux
 	newTio.c_line = 0;
 #endif
-	ioctl(0, TCSETA, &newTio);
+	tcsetattr(0, TCSAFLUSH, &newTio);
 	/* VGA initialize */
 	VtStart();
 	ConsoleStart();
 	init.display = TRUE;
+#ifndef	MINI_KON
 	FontAttach();
+#endif
 	ConsoleHandler();
     } else {
 	int	efd;
@@ -427,7 +465,7 @@ void	TermStart(void)
 	}
 	close(masterPty);
 	/* Set old tio to TTY */
-	ioctl(slavePty, TCSETA, &oldTio);
+	tcsetattr(slavePty, TCSAFLUSH, &oldTio);
 #ifdef __FreeBSD__
 	ioctl(slavePty, TIOCSCTTY, (char *)0);
 #endif
