@@ -36,10 +36,8 @@
 #endif
 #include	<fcntl.h>
 #include	<signal.h>
-#if defined(linux)
-#include	<termio.h>
-#elif defined(__FreeBSD__)
 #include	<termios.h>
+#if defined(__FreeBSD__)
 #include	<machine/console.h>
 #endif
 #include	<sys/ioctl.h>
@@ -53,7 +51,9 @@
 #include	<defs.h>
 #include	<errors.h>
 #include	<fnld.h>
+#ifndef	MINI_KON
 #include	<mouse.h>
+#endif
 #include	<vc.h>
 #include	<vt.h>
 #include	<term.h>
@@ -61,7 +61,9 @@
 struct dispInfo		dInfo;
 struct cursorInfo	cInfo;
 struct videoInfo	vInfo;
+#ifndef	MINI_KON
 static struct cursorInfo	mouseCursor;
+#endif
 
 static bool	textClear;
 
@@ -159,6 +161,7 @@ void	TextDeleteChar(int n)
     
     bmove(textBuff + addr, textBuff + addr + n, dx);
     bmove(attrBuff + addr, attrBuff + addr + n, dx);
+    bmove(flagBuff + addr, flagBuff + addr + n, dx);
     blatch(flagBuff + addr, dx);
     
     addr = TextAddress(dInfo.glineByte - n, con.y);
@@ -173,11 +176,12 @@ void	TextInsertChar(int n)
     
     addr = TextAddress(dInfo.txmax, con.y);
     dx = dInfo.glineByte - con.x - n;
-    
     brmove(textBuff + addr, textBuff + addr - n, dx);
     brmove(attrBuff + addr, attrBuff + addr - n, dx);
+    brmove(flagBuff + addr, flagBuff + addr - n, dx);
     
     addr = TextAddress(con.x, con.y);
+
     blatch(flagBuff + addr + n, dx);
     bzero2(textBuff + addr, n);
     bzero2(attrBuff + addr, n);
@@ -195,7 +199,9 @@ void	TextRefresh(void)
 	return;
     }
     ShowCursor(&cInfo, FALSE);
+#ifndef	MINI_KON
     ShowCursor(&mouseCursor, FALSE);
+#endif
     if (textClear) vInfo.clear_all();
     if (useHardScroll) {
 	if (scrollLine > 0) vInfo.hard_scroll_up(scrollLine);
@@ -418,10 +424,22 @@ void TextSput(u_char ch)
 
 void TextClearAll(void)
 {
+#if 1
+    u_int y, addr;
+
+    for (y = 0; y <= con.ymax; y ++) {
+	addr = TextAddress(0, y);
+	lzero(textBuff + addr, dInfo.glineByte);
+	lzero(attrBuff + addr, dInfo.glineByte);
+    }
+#else
     lzero(textBuff, textSize);
     lzero(attrBuff, textSize);
+#endif
     lzero(flagBuff, textSize);
+#ifndef	MINI_KON
     mInfo.sw = 0;
+#endif
     textClear = TRUE;
 }
 
@@ -470,7 +488,7 @@ void	TextClearEos(u_char mode)
 	bzero2(flagBuff + addr, con.x);/* needless to latch */
 	break;
     default:
-	for (y = con.y + 1; y <= dInfo.tymax; y ++) {
+	for (y = con.y + 1; y <= con.ymax; y ++) {
 	    addr = TextAddress(0, y);
 	    lzero(textBuff + addr, dInfo.glineByte);
 	    lzero(attrBuff + addr, dInfo.glineByte);
@@ -698,6 +716,7 @@ static void	SaveScreen(bool save)
     saverCount = 0;
 }
 
+#ifndef	MINI_KON
 static void PollMouseCursor(void)
 {
     ShowCursor(&mouseCursor, FALSE);
@@ -713,6 +732,7 @@ static void PollMouseCursor(void)
 	}
     }
 }
+#endif
 
 /* Called when some action was over, or every 1/10 sec when idle. */
 
@@ -723,7 +743,9 @@ void	PollCursor(bool wakeup)
     if (wakeup) {
 	SaveScreen(FALSE);
 	ShowCursor(&cInfo, TRUE);
+#ifndef	MINI_KON
 	PollMouseCursor();
+#endif
 	return;
     }
     /* Idle. */
@@ -731,16 +753,20 @@ void	PollCursor(bool wakeup)
 	return;
     if ((saveTime > 0) && (++saverCount == saveTime)) {
 	ShowCursor(&cInfo, FALSE);
+#ifndef	MINI_KON
 	ShowCursor(&mouseCursor, FALSE);
+#endif
 	SaveScreen(TRUE);
 	return;
     }
     if ((cInfo.interval > 0) && (++cInfo.count == cInfo.interval)) {
 	ToggleCursor(&cInfo);
     }
+#ifndef	MINI_KON
     if (mInfo.has_mouse) {
 	PollMouseCursor();
     }
+#endif
 }
 
 /* Configuration routines. */
@@ -756,10 +782,12 @@ static struct videoconf {
 } videos[] = {
 #ifdef	HAS_VGA
     {"VGA", SvgaSetVideoType},
+#ifndef	MINI_KON
     {"VGAFM", VgaFmSetVideoType},
     {"EGA", SvgaSetVideoType},
     {"SVGA", SvgaSetVideoType},
 #endif
+#endif
 #ifdef	HAS_S3
     {"S3", S3SetVideoType},
 #endif
@@ -836,7 +864,10 @@ void	Beep(void)
 
 static int	ConfigInterval(const char *confstr)
 {
-    cInfo.interval = mouseCursor.interval = atoi(confstr);
+    cInfo.interval = atoi(confstr);
+#ifndef	MINI_KON
+    mouseCursor.interval = cInfo.interval;
+#endif
     return SUCCESS;
 }
 
@@ -867,8 +898,11 @@ void	ConsoleStart(void)
     ioctl(0, KDSETMODE, KD_GRAPHICS);
     ioctl(0, TIOCGWINSZ, &text_win);
     vInfo.init();
-    cInfo.shown = mouseCursor.shown = FALSE;
+    cInfo.shown = FALSE;
+#ifndef	MINI_KON
+    mouseCursor.shown = FALSE;
     mouseCursor.sw = TRUE;
+#endif
     saved = FALSE;
     GraphMode();
 }
