@@ -28,14 +28,14 @@
 #include	<stdio.h>
 #include	<unistd.h>
 #include	<string.h>
+#include	<termios.h>
 #if defined(linux)
-#include	<termio.h>
 #include	<malloc.h>
 #elif defined(__FreeBSD__)
-#include	<termios.h>
 #include	<stdlib.h>
 #endif
 #include	<sys/types.h>
+#include	<sys/ioctl.h>
 
 #include	<getcap.h>
 #include	<defs.h>
@@ -78,51 +78,53 @@ static struct attrStack *saveAttr;
 static int	scroll;			 /* Կ */
 struct langInfo lInfo;
 
-static
-    void SaveAttr()
+static void
+SaveAttr(struct attrStack **asp)
 {
     struct attrStack *tmp;
 
     tmp = (struct attrStack *)malloc(sizeof(struct attrStack));
-    if (saveAttr) tmp->prev = saveAttr;
-    else tmp->prev = NULL;
-    saveAttr = tmp;
-    saveAttr->x = con.x;
-    saveAttr->y = con.y;
-    saveAttr->attr = con.attr;
-    saveAttr->fcol = con.fcol;
-    saveAttr->bcol = con.bcol;
+    if (!asp) {
+	if (saveAttr) tmp->prev = saveAttr;
+	else tmp->prev = NULL;
+	saveAttr = tmp;
+    } else *asp = tmp;
+    tmp->x = con.x;
+    tmp->y = con.y;
+    tmp->attr = con.attr;
+    tmp->fcol = con.fcol;
+    tmp->bcol = con.bcol;
 }
 
-static
-    void RestoreAttr()
+static void
+RestoreAttr(struct attrStack *asp)
 {
-    struct attrStack *tmp;
-
-    if (saveAttr) {
-	con.x = saveAttr->x;
-	con.y = saveAttr->y;
-	con.attr = saveAttr->attr;
-	con.fcol = saveAttr->fcol;
-	con.bcol = saveAttr->bcol;
-	tmp = saveAttr;
-	saveAttr = tmp->prev;
-	free(tmp);
+    if (!asp) {
+	if ((asp = saveAttr) == NULL) return;
+	saveAttr = asp->prev;
     }
+    con.x = asp->x;
+    con.y = asp->y;
+    if (con.y < con.ymin) con.y = con.ymin;
+    if (con.y > con.ymax) con.y = con.ymax;
+    con.attr = asp->attr;
+    con.fcol = asp->fcol;
+    con.bcol = asp->bcol;
+    free(asp);
 }
 
 static void	EscSetAttr(int col)
 {
     static u_char table[] = {0, 4, 2, 6, 1, 5, 3, 7};
     u_char	swp;
-    
+
     switch(col) {
     case 0:	/* off all attributes */
 	con.bcol = 0;
 	con.fcol = 7;
 	con.attr = 0;
 	break;
-    case 1:	/*  */
+    case 1:	/* highlight */
 	con.attr |= ATTR_HIGH;
 	if (con.fcol) con.fcol |= 8;
 	break;
@@ -158,6 +160,12 @@ static void	EscSetAttr(int col)
 	    con.bcol = swp;
 	}
 	break;
+    case 10:
+	if (con.trans == CS_GRAPH) con.trans = CS_LEFT;
+	break;
+    case 11:
+	con.trans = CS_GRAPH;
+	break;
     default:
 	if (col >= 30 && col <= 37) {
 	    swp = table[col - 30];
@@ -194,11 +202,11 @@ static void	VtSetMode(u_char mode, bool sw)
     }
 }
 
-static
-    void EscReport(u_char mode, u_short arg)
+static void
+EscReport(u_char mode, u_short arg)
 {
     static char report[LEN_REPORT];
-    
+
     switch(mode) {
     case 'n':
 	if (arg == 6) {
@@ -215,10 +223,79 @@ static
     write(masterPty, report, strlen(report));
 }
 
+static void
+SetRegion(int ymin, int ymax)
+{
+    con.ymin = ymin;
+    con.ymax = ymax;
+    con.x = 0;
+    if (con.y < con.ymin || con.y > con.ymax) con.y = con.ymin;
+    con.wrap = FALSE;
+    if (con.ymin || con.ymax != dInfo.tymax)
+	con.soft = TRUE;
+    else
+	con.soft = FALSE;
+}
+
+void
+SetWinSize()
+{
+    struct winsize win;
+
+    win.ws_row = con.ymax + 1;
+    win.ws_col = dInfo.txmax + 1;
+    win.ws_xpixel = win.ws_ypixel = 0;
+    ioctl(masterPty, TIOCSWINSZ, &win);
+}
+
+static void
+EscStatusLine(u_char mode)
+{
+    static void EscBracket(u_char);
+    static struct attrStack *asp;
+
+    switch(mode) {
+    case 'T':	/* To */
+	if (con.sl == SL_ENTER) break;
+	if (!asp) SaveAttr(&asp);
+    case 'S':	/* Show */
+	if (con.sl == SL_NONE) {
+	    con.ymax = dInfo.tymax - 1;
+	    SetWinSize();
+	}
+	if (mode == 'T') {
+	    con.sl = SL_ENTER;
+	    SetRegion(dInfo.tymax, dInfo.tymax);
+	}
+	break;
+    case 'F':	/* From */
+	if (con.sl == SL_ENTER) {
+	    con.sl = SL_LEAVE;
+	    SetRegion(0, dInfo.tymax - 1);
+	    if (asp) RestoreAttr(asp);
+	    asp = NULL;
+	}
+	break;
+    case 'H':	/* Hide */
+    case 'E':	/* Erase */
+	if (con.sl == SL_NONE) break;
+	SetRegion(0, dInfo.tymax);
+	SetWinSize();
+	con.sl = SL_NONE;
+	break;
+    default:
+	con.esc = EscBracket;
+	EscBracket(mode);
+	return;
+    }
+    con.wrap = FALSE;
+    con.esc = NULL;
+}
+
 #define	MAX_NARG	8
 
-static
-    void EscBracket(u_char ch)
+static void
+EscBracket(u_char ch)
 {
     u_char	n;
     static u_short varg[MAX_NARG], narg, question;
@@ -227,8 +304,10 @@ static
 	varg[narg] = (varg[narg] * 10) + (ch - '0');
     } else if (ch == ';') {
 	/*  MAX_NARG ޤǤݡȤʤ!! */
-	if (narg < MAX_NARG) narg ++;
-	else con.esc = NULL;
+	if (narg < MAX_NARG) {
+	    narg ++;
+	    varg[narg] = 0;
+	} else con.esc = NULL;
     } else {
 	con.esc = NULL;
 	switch(ch) {
@@ -291,15 +370,11 @@ static
 		EscSetAttr(varg[n]);
 	    break;
 	case 'r':
-	    con.ymin = varg[0]? (varg[0] - 1): 0;
-	    con.ymax = varg[1]? (varg[1] - 1): dInfo.tymax;
-	    con.x = 0;
-	    con.y = con.ymin;
-	    con.wrap = FALSE;
-	    if (con.ymin || con.ymax != dInfo.tymax)
-		con.soft = TRUE;
-	    else
-		con.soft = FALSE;
+	    n = varg[1] ? (varg[1] - 1): dInfo.tymax;
+	    if (con.sl != SL_NONE) {
+		if (n == dInfo.tymax) n --;
+	    }
+	    SetRegion(varg[0] ? (varg[0] - 1): 0, n);
 	    break;
 	case 'l':
 	    for (n = 0; n <= narg; n ++)
@@ -310,14 +385,17 @@ static
 		VtSetMode(varg[n], TRUE);
 	    break;
 	case '?':
+	    con.esc = EscStatusLine;
+#if 0
 	    question = TRUE;
 	    con.esc = EscBracket;
+#endif
 	    break;
 	case 's':
-	    SaveAttr();
+	    SaveAttr(NULL);
 	    break;
 	case 'u':
-	    RestoreAttr();
+	    RestoreAttr(NULL);
 	    break;
 	case 'n':
 	case 'c':
@@ -369,6 +447,9 @@ static
     int i=0;
 
     switch(ch) {
+    case '0':
+	con.g[0] = CS_GRAPH;
+	break;
     case 'U':
 	con.g[0] = CS_GRAPH;
 	break;
@@ -452,10 +533,10 @@ static
 	TextClearAll();
 	break;
     case '7':
-	SaveAttr();
+	SaveAttr(NULL);
 	break;
     case '8':
-	RestoreAttr();
+	RestoreAttr(NULL);
 	con.wrap = FALSE;
 	break;
     }
@@ -516,8 +597,10 @@ void	VtEmu(const char *buff, int nchars)
 #endif
 	case CHAR_LF:
 	    con.wrap = FALSE;
-	    if (con.y == con.ymax) scroll ++;
-	    else con.y ++;
+/*	    if (con.sl != SL_ENTER) {*/
+		if (con.y == con.ymax) scroll ++;
+		else con.y ++;
+/*	    }*/
 	    break;
 	case CHAR_CR:
 	    con.x = 0;
@@ -535,13 +618,16 @@ void	VtEmu(const char *buff, int nchars)
 /*	case ' ': con.trans = CS_LEFT;*/
 	default:
 	    if (con.x == con.xmax + 1) {
+printf("here0(%d)\r\n", con.x);
 		con.wrap = TRUE;
 		con.x --;
 	    }
 	    if (con.wrap) {
 		con.x -= con.xmax;
-		if (con.y == con.ymax) scroll ++;
-		else con.y ++;
+/*		if (con.sl != SL_ENTER) {*/
+		    if (con.y == con.ymax) scroll ++;
+		    else con.y ++;
+/*		}*/
 		con.wrap = FALSE;
 		buff --;
 		nchars ++;
@@ -574,14 +660,12 @@ void	VtEmu(const char *buff, int nchars)
 		con.x += 2;
 		con.knj1 = 0;
 		continue;
-#if 1
 	    } else if (con.trans == CS_DBCS
 		       || (iskanji(ch) && con.trans == CS_LEFT)) {
 		/*  1 ⡼ */
 		if (con.x == con.xmax) con.wrap = TRUE;
 		con.knj1 = ch;
 		continue;
-#endif
 	    } else {
 		/* ANK ⡼ */
 		if (con.ins) TextInsertChar(1);
@@ -597,6 +681,11 @@ void	VtEmu(const char *buff, int nchars)
 	}
 	scroll = 0;
     }
+    if (con.x == con.xmax + 1) {
+printf("here1(%d)\r\n", con.x);
+	con.wrap = TRUE;
+	con.x --;
+    }
 }
 
 static int	ConfigCoding(const char *confstr)
